[asterisk-commits] trunk - r7353 /trunk/apps/app_queue.c

asterisk-commits at lists.digium.com asterisk-commits at lists.digium.com
Mon Dec 5 18:25:14 CST 2005


Author: tilghman
Date: Mon Dec  5 18:25:13 2005
New Revision: 7353

URL: http://svn.digium.com/view/asterisk?rev=7353&view=rev
Log:
Clarify purpose of function, by renaming

Modified:
    trunk/apps/app_queue.c

Modified: trunk/apps/app_queue.c
URL: http://svn.digium.com/view/asterisk/trunk/apps/app_queue.c?rev=7353&r1=7352&r2=7353&view=diff
==============================================================================
--- trunk/apps/app_queue.c (original)
+++ trunk/apps/app_queue.c Mon Dec  5 18:25:13 2005
@@ -760,7 +760,7 @@
    \return Return the queue, or NULL if it doesn't exist.
    \note Should be called with the global qlock locked.
    When found, the queue is returned with q->lock locked. */
-static struct ast_call_queue *reload_queue_rt(const char *queuename, struct ast_variable *queue_vars, struct ast_config *member_config)
+static struct ast_call_queue *find_queue_by_name_rt(const char *queuename, struct ast_variable *queue_vars, struct ast_config *member_config)
 {
 	struct ast_variable *v;
 	struct ast_call_queue *q, *prev_q;
@@ -914,8 +914,8 @@
 	}
 
 	ast_mutex_lock(&qlock);
-	q = reload_queue_rt(queuename, queue_vars, member_config);
-	/* Note: If found, reload_queue_rt() returns with q->lock locked. */
+	q = find_queue_by_name_rt(queuename, queue_vars, member_config);
+	/* Note: If found, find_queue_by_name_rt() returns with q->lock locked. */
 	if(member_config)
 		ast_config_destroy(member_config);
 	if(queue_vars)



More information about the asterisk-commits mailing list